# DEV
# 0.0.5
- Remove jwt
- Include port in AWS_S3_CUSTOM_DOMAIN if specified
- Add django-configurations as a dependency
# 0.0.4
- Update celery config for beat scheduler
- Remove default custom aws domain
# 0.0.3
- Change Dev to use console email backend
# 0.0.2
- Remove swagger
- Move `login_url` configuration to DRF settings
# 0.0.1
- Initial upload
